import { query } from '@/modules/query';
import { Query } from '@kevisual/query';
import { DataOpts } from '@kevisual/query/query';

export class QueryChat {
  query: Query;

  constructor({ query }: { query: Query }) {
    this.query = query;
  }

  getChatList(opts?: DataOpts) {
    return this.query.post(
      {
        path: 'ai',
        key: 'get-chat-list',
      },
      opts,
    );
  }

  getChat(id: string, opts?: DataOpts) {
    return this.query.post(
      {
        path: 'ai',
        key: 'get-chat',
        data: {
          id,
        },
      },
      opts,
    );
  }
  updateChat(data: any, opts?: DataOpts) {
    return this.query.post(
      {
        path: 'ai',
        key: 'update-chat',
        data,
      },
      opts,
    );
  }

  deleteChat(id: string, opts?: DataOpts) {
    return this.query.post(
      {
        path: 'ai',
        key: 'delete-chat',
        data: {
          id,
        },
      },
      opts,
    );
  }
  /**
   * 获取模型列表
   * @param opts
   * @returns
   */
  getModelList(data?: { usernames?: string[] }, opts?: DataOpts) {
    return this.query.post(
      {
        path: 'ai',
        key: 'get-model-list',
        data,
      },
      opts,
    );
  }
  /**
   * 聊天对话模型
   * @param data
   * @param chatOpts
   * @param opts
   * @returns
   */
  chat(data: ChatDataOpts, chatOpts: ChatOpts, opts?: DataOpts) {
    const { username, model, group, getFull = true } = chatOpts;
    if (!username || !model || !group) {
      throw new Error('username, model, group is required');
    }
    return this.query.post(
      {
        path: 'ai',
        key: 'chat',
        ...chatOpts,
        getFull,
        data,
      },
      opts,
    );
  }
  clearConfigCache(opts?: DataOpts) {
    return this.query.post(
      {
        path: 'ai',
        key: 'clear-cache',
      },
      opts,
    );
  }
  /**
   * 获取聊天使用情况
   * @param opts
   * @returns
   */
  getChatUsage(opts?: DataOpts) {
    return this.query.post(
      {
        path: 'ai',
        key: 'get-chat-usage',
      },
      opts,
    );
  }

  /**
   * 清除当前用户模型自己的统计
   * @param opts
   * @returns
   */
  clearSelfUsage(opts?: DataOpts) {
    return this.query.post(
      {
        path: 'ai',
        key: 'clear-chat-limit',
      },
      opts,
    );
  }
}
export type ChatDataOpts = {
  id?: string;
  title?: string;
  messages?: any[];
  data?: any;
  type?: 'temp' | 'keep' | string;
};
export type ChatOpts = {
  username: string;
  model: string;
  /**
   * 获取完整消息回复
   */
  getFull?: boolean;
  group: string;
  /**
   * openai的参数
   */
  options?: any;
};
